@@ -66,7 +66,7 @@ const redirectableResources = new Map([
     } ],
     [ 'ampproject_v0.js', {
         alias: 'ampproject.org/v0.js',
-    } ],
+    } ],  
     [ 'chartbeat.js', {
         alias: 'static.chartbeat.com/chartbeat.js',
     } ],
@@ -83,6 +83,9 @@ const redirectableResources = new Map([
     [ 'fingerprint2.js', {
         data: 'text',
     } ],
+    [ 'fingerprint3.js', {
+        data: 'text',
+    } ],
     [ 'google-analytics_analytics.js', {
         alias: [
             'google-analytics.com/analytics.js',
@@ -130,6 +133,9 @@ const redirectableResources = new Map([
         alias: 'bab-defuser.js',
         data: 'text',
     } ],
+    [ 'nobab2.js', {
+        data: 'text',
+    } ],
     [ 'nofab.js', {
         alias: 'fuckadblock.js-3.2.0',
         data: 'text',
@@ -138,6 +144,8 @@ const redirectableResources = new Map([
         alias: [ 'noopmp3-0.1s', 'abp-resource:blank-mp3' ],
         data: 'blob',
     } ],
+    [ 'noop-0.5s.mp3', {
+    } ],
     [ 'noop-1s.mp4', {
         alias: 'noopmp4-1s',
         data: 'blob',
@@ -167,6 +175,9 @@ const redirectableResources = new Map([
     [ 'popads-dummy.js', {
         data: 'text',
     } ],
+    [ 'prebid-ads.js', {
+        data: 'text',
+    } ],
     [ 'scorecardresearch_beacon.js', {
         alias: 'scorecardresearch.com/beacon.js',
     } ],
