@@ -117,7 +117,8 @@ const contentscriptCode = (( ) => {
         ')(',
             '"', 'hostname-slot', '", ',
             '"', 'scriptlets-slot', '"',
-        '); void 0;',
+        ');',
+        '\n0;',
     ];
     return {
         parts: parts,
@@ -221,18 +222,15 @@ const patchScriptlet = function(content, args) {
     return content;
 };
 
-const logOne = function(isException, token, details) {
+const logOne = function(tabId, url, filter) {
     µb.filteringContext
         .duplicate()
-        .fromTabId(details.tabId)
+        .fromTabId(tabId)
         .setRealm('extended')
         .setType('dom')
-        .setURL(details.url)
-        .setDocOriginFromURL(details.url)
-        .setFilter({
-            source: 'extended',
-            raw: (isException ? '#@#' : '##') + `+js(${token})`
-        })
+        .setURL(url)
+        .setDocOriginFromURL(url)
+        .setFilter({ source: 'extended', raw: filter })
         .toLogger();
 };
 
@@ -249,7 +247,7 @@ scriptletFilteringEngine.freeze = function() {
 };
 
 scriptletFilteringEngine.compile = function(parser, writer) {
-    writer.select(µb.compiledScriptletSection);
+    writer.select('SCRIPTLET_FILTERS');
 
     // Only exception filters are allowed to be global.
     const { raw, exception } = parser.result;
@@ -295,7 +293,7 @@ scriptletFilteringEngine.compileTemporary = function(parser) {
 //     4                 -1
 
 scriptletFilteringEngine.fromCompiledContent = function(reader) {
-    reader.select(µb.compiledScriptletSection);
+    reader.select('SCRIPTLET_FILTERS');
 
     while ( reader.next() ) {
         acceptedCount += 1;
@@ -319,7 +317,7 @@ const $scriptlets = new Set();
 const $exceptions = new Set();
 const $scriptletToCodeMap = new Map();
 
-scriptletFilteringEngine.retrieve = function(request) {
+scriptletFilteringEngine.retrieve = function(request, options = {}) {
     if ( scriptletDB.size === 0 ) { return; }
 
     const hostname = request.hostname;
@@ -346,29 +344,38 @@ scriptletFilteringEngine.retrieve = function(request) {
         return;
     }
 
+    const mustLog = Array.isArray(options.logEntries);
+
     // Wholly disable scriptlet injection?
     if ( $exceptions.has('') ) {
-        if ( logger.enabled ) {
-            logOne(true, '', request);
+        if ( mustLog ) {
+            logOne(request.tabId, request.url, '#@#+js()');
         }
         return;
     }
 
     $scriptletToCodeMap.clear();
-    for ( const rawToken of $scriptlets ) {
-        lookupScriptlet(rawToken, redirectEngine, $scriptletToCodeMap);
+    for ( const token of $scriptlets ) {
+        lookupScriptlet(token, redirectEngine, $scriptletToCodeMap);
     }
     if ( $scriptletToCodeMap.size === 0 ) { return; }
 
     // Return an array of scriptlets, and log results if needed.
     const out = [];
-    for ( const [ rawToken, code ] of $scriptletToCodeMap ) {
-        const isException = $exceptions.has(rawToken);
+    for ( const [ token, code ] of $scriptletToCodeMap ) {
+        const isException = $exceptions.has(token);
         if ( isException === false ) {
             out.push(code);
         }
-        if ( logger.enabled ) {
-            logOne(isException, rawToken, request);
+        if ( mustLog === false ) { continue; }
+        if ( isException ) {
+            logOne(request.tabId, request.url, `#@#+js(${token})`);
+        } else {
+            options.logEntries.push({
+                token: `##+js(${token})`,
+                tabId: request.tabId,
+                url: request.url,
+            });
         }
     }
 
@@ -411,18 +418,26 @@ scriptletFilteringEngine.injectNow = function(details) {
     };
     request.domain = domainFromHostname(request.hostname);
     request.entity = entityFromDomain(request.domain);
-    const scriptlets = this.retrieve(request);
+    const logEntries = logger.enabled ? [] : undefined;
+    const scriptlets = this.retrieve(request, { logEntries });
     if ( scriptlets === undefined ) { return; }
     let code = contentscriptCode.assemble(request.hostname, scriptlets);
     if ( µb.hiddenSettings.debugScriptletInjector ) {
         code = 'debugger;\n' + code;
     }
-    vAPI.tabs.executeScript(details.tabId, {
+    const promise = vAPI.tabs.executeScript(details.tabId, {
         code,
         frameId: details.frameId,
         matchAboutBlank: true,
         runAt: 'document_start',
     });
+    if ( logEntries === undefined ) { return; }
+    promise.then(results => {
+        if ( Array.isArray(results) === false || results[0] !== 0 ) { return; }
+        for ( const entry of logEntries ) {
+            logOne(entry.tabId, entry.url, entry.token);
+        }
+    });
 };
 
 scriptletFilteringEngine.toSelfie = function() {
